@@ -1,13 +1,10 @@
+#' @export
 rforcecom.queryMore <-
 function(session, nextRecordsUrl){
+
  # Trim the first slash
  nextRecordsUrl <- sub("^/", "", nextRecordsUrl)
- 
- # Load packages
- #if(!require(XML)){ install.packages("XML"); stop(!require(XML)) }
- #if(!require(RCurl)){ install.packages("RCurl"); stop(!require(RCurl)) }
- #if(!require(plyr)){ install.packages("plyr"); stop(!require(plyr)) }
- 
+
  # Retrieve XML via REST API
  h <- basicHeaderGatherer()
  t <- basicTextGatherer()
@@ -54,7 +51,10 @@ function(session, nextRecordsUrl){
  xdf <- subset(xdf, select=!grepl('\\.attrs\\.', names(xdf)))
  
  # Convert charset from UTF-8
- xdf.iconv <- data.frame(lapply(xdf, iconv, from="UTF-8", to=""))
+ xdf.iconv <- data.frame(lapply(xdf, iconv, from="UTF-8", to=""), stringsAsFactors=FALSE)
+ 
+ # Convert strings to correct data types
+ xdf.iconv <- lapply(xdf.iconv, type.convert)
  
  # Check whether it has next record
  try(nextRecordsUrl <- iconv(xmlValue(x.root[['nextRecordsUrl']]), from="UTF-8", to=""), TRUE)
